@@ -17,6 +17,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import ros_cdk_core
@@ -33,7 +35,7 @@ class RosTrail(
         self,
         scope: ros_cdk_core.Construct,
         id: builtins.str,
-        props: "RosTrailProps",
+        props: typing.Union["RosTrailProps", typing.Dict[str, typing.Any]],
         enable_resource_property_constraint: builtins.bool,
     ) -> None:
         '''Create a new ``ALIYUN::ACTIONTRAIL::Trail``.
@@ -43,6 +45,12 @@ class RosTrail(
         :param props: - resource properties.
         :param enable_resource_property_constraint: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(RosTrail.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
+            check_type(argname="argument enable_resource_property_constraint", value=enable_resource_property_constraint, expected_type=type_hints["enable_resource_property_constraint"])
         jsii.create(self.__class__, self, [scope, id, props, enable_resource_property_constraint])
 
     @jsii.member(jsii_name="renderProperties")
@@ -53,15 +61,18 @@ class RosTrail(
         '''
         :param props: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(RosTrail._render_properties)
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="ROS_RESOURCE_TYPE_NAME")
     def ROS_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         '''The resource type name for this resource class.'''
         return typing.cast(builtins.str, jsii.sget(cls, "ROS_RESOURCE_TYPE_NAME"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrName")
     def attr_name(self) -> ros_cdk_core.IResolvable:
         '''
@@ -69,21 +80,24 @@ class RosTrail(
         '''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrName"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="rosProperties")
     def _ros_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "rosProperties"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="enableResourcePropertyConstraint")
     def enable_resource_property_constraint(self) -> builtins.bool:
         return typing.cast(builtins.bool, jsii.get(self, "enableResourcePropertyConstraint"))
 
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(RosTrail, "enable_resource_property_constraint").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="name")
     def name(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
         '''
@@ -93,9 +107,12 @@ class RosTrail(
 
     @name.setter
     def name(self, value: typing.Union[builtins.str, ros_cdk_core.IResolvable]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(RosTrail, "name").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="ossBucketName")
     def oss_bucket_name(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
         '''
@@ -108,9 +125,12 @@ class RosTrail(
         self,
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(RosTrail, "oss_bucket_name").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "ossBucketName", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="roleName")
     def role_name(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
         '''
@@ -123,9 +143,12 @@ class RosTrail(
         self,
         value: typing.Union[builtins.str, ros_cdk_core.IResolvable],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(RosTrail, "role_name").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "roleName", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="eventRw")
     def event_rw(
         self,
@@ -140,9 +163,12 @@ class RosTrail(
         self,
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(RosTrail, "event_rw").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "eventRw", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="ossKeyPrefix")
     def oss_key_prefix(
         self,
@@ -157,9 +183,12 @@ class RosTrail(
         self,
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(RosTrail, "oss_key_prefix").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "ossKeyPrefix", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="slsProjectArn")
     def sls_project_arn(
         self,
@@ -174,9 +203,12 @@ class RosTrail(
         self,
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(RosTrail, "sls_project_arn").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "slsProjectArn", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="slsWriteRoleArn")
     def sls_write_role_arn(
         self,
@@ -191,6 +223,9 @@ class RosTrail(
         self,
         value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(RosTrail, "sls_write_role_arn").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "slsWriteRoleArn", value)
 
 
@@ -205,7 +240,7 @@ class RosTrailLogging(
         self,
         scope: ros_cdk_core.Construct,
         id: builtins.str,
-        props: "RosTrailLoggingProps",
+        props: typing.Union["RosTrailLoggingProps", typing.Dict[str, typing.Any]],
         enable_resource_property_constraint: builtins.bool,
     ) -> None:
         '''Create a new ``ALIYUN::ACTIONTRAIL::TrailLogging``.
@@ -215,6 +250,12 @@ class RosTrailLogging(
         :param props: - resource properties.
         :param enable_resource_property_constraint: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(RosTrailLogging.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
+            check_type(argname="argument enable_resource_property_constraint", value=enable_resource_property_constraint, expected_type=type_hints["enable_resource_property_constraint"])
         jsii.create(self.__class__, self, [scope, id, props, enable_resource_property_constraint])
 
     @jsii.member(jsii_name="renderProperties")
@@ -225,15 +266,18 @@ class RosTrailLogging(
         '''
         :param props: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(RosTrailLogging._render_properties)
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="ROS_RESOURCE_TYPE_NAME")
     def ROS_RESOURCE_TYPE_NAME(cls) -> builtins.str:
         '''The resource type name for this resource class.'''
         return typing.cast(builtins.str, jsii.sget(cls, "ROS_RESOURCE_TYPE_NAME"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrIsLogging")
     def attr_is_logging(self) -> ros_cdk_core.IResolvable:
         '''
@@ -241,7 +285,7 @@ class RosTrailLogging(
         '''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrIsLogging"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrLatestDeliveryError")
     def attr_latest_delivery_error(self) -> ros_cdk_core.IResolvable:
         '''
@@ -249,7 +293,7 @@ class RosTrailLogging(
         '''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrLatestDeliveryError"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrLatestDeliveryTime")
     def attr_latest_delivery_time(self) -> ros_cdk_core.IResolvable:
         '''
@@ -257,7 +301,7 @@ class RosTrailLogging(
         '''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrLatestDeliveryTime"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrStartLoggingTime")
     def attr_start_logging_time(self) -> ros_cdk_core.IResolvable:
         '''
@@ -265,7 +309,7 @@ class RosTrailLogging(
         '''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrStartLoggingTime"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrStopLoggingTime")
     def attr_stop_logging_time(self) -> ros_cdk_core.IResolvable:
         '''
@@ -273,12 +317,12 @@ class RosTrailLogging(
         '''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrStopLoggingTime"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="rosProperties")
     def _ros_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "rosProperties"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="enable")
     def enable(self) -> typing.Union[builtins.bool, ros_cdk_core.IResolvable]:
         '''
@@ -291,18 +335,24 @@ class RosTrailLogging(
         self,
         value: typing.Union[builtins.bool, ros_cdk_core.IResolvable],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(RosTrailLogging, "enable").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enable", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="enableResourcePropertyConstraint")
     def enable_resource_property_constraint(self) -> builtins.bool:
         return typing.cast(builtins.bool, jsii.get(self, "enableResourcePropertyConstraint"))
 
     @enable_resource_property_constraint.setter
     def enable_resource_property_constraint(self, value: builtins.bool) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(RosTrailLogging, "enable_resource_property_constraint").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableResourcePropertyConstraint", value)
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="name")
     def name(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
         '''
@@ -312,6 +362,9 @@ class RosTrailLogging(
 
     @name.setter
     def name(self, value: typing.Union[builtins.str, ros_cdk_core.IResolvable]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(RosTrailLogging, "name").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
 
@@ -332,6 +385,10 @@ class RosTrailLoggingProps:
         :param enable: 
         :param name: 
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(RosTrailLoggingProps.__init__)
+            check_type(argname="argument enable", value=enable, expected_type=type_hints["enable"])
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
         self._values: typing.Dict[str, typing.Any] = {
             "enable": enable,
             "name": name,
@@ -402,6 +459,15 @@ class RosTrailProps:
         :param sls_project_arn: 
         :param sls_write_role_arn: 
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(RosTrailProps.__init__)
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
+            check_type(argname="argument oss_bucket_name", value=oss_bucket_name, expected_type=type_hints["oss_bucket_name"])
+            check_type(argname="argument role_name", value=role_name, expected_type=type_hints["role_name"])
+            check_type(argname="argument event_rw", value=event_rw, expected_type=type_hints["event_rw"])
+            check_type(argname="argument oss_key_prefix", value=oss_key_prefix, expected_type=type_hints["oss_key_prefix"])
+            check_type(argname="argument sls_project_arn", value=sls_project_arn, expected_type=type_hints["sls_project_arn"])
+            check_type(argname="argument sls_write_role_arn", value=sls_write_role_arn, expected_type=type_hints["sls_write_role_arn"])
         self._values: typing.Dict[str, typing.Any] = {
             "name": name,
             "oss_bucket_name": oss_bucket_name,
@@ -506,7 +572,7 @@ class Trail(
         self,
         scope: ros_cdk_core.Construct,
         id: builtins.str,
-        props: "TrailProps",
+        props: typing.Union["TrailProps", typing.Dict[str, typing.Any]],
         enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''Create a new ``ALIYUN::ACTIONTRAIL::Trail``.
@@ -520,9 +586,15 @@ class Trail(
         :param props: -
         :param enable_resource_property_constraint: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Trail.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
+            check_type(argname="argument enable_resource_property_constraint", value=enable_resource_property_constraint, expected_type=type_hints["enable_resource_property_constraint"])
         jsii.create(self.__class__, self, [scope, id, props, enable_resource_property_constraint])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrName")
     def attr_name(self) -> ros_cdk_core.IResolvable:
         '''Attribute Name: The name of the trail to be created, which must be unique for an account.'''
@@ -540,7 +612,7 @@ class TrailLogging(
         self,
         scope: ros_cdk_core.Construct,
         id: builtins.str,
-        props: "TrailLoggingProps",
+        props: typing.Union["TrailLoggingProps", typing.Dict[str, typing.Any]],
         enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''Create a new ``ALIYUN::ACTIONTRAIL::TrailLogging``.
@@ -554,33 +626,39 @@ class TrailLogging(
         :param props: -
         :param enable_resource_property_constraint: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(TrailLogging.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
+            check_type(argname="argument enable_resource_property_constraint", value=enable_resource_property_constraint, expected_type=type_hints["enable_resource_property_constraint"])
         jsii.create(self.__class__, self, [scope, id, props, enable_resource_property_constraint])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrIsLogging")
     def attr_is_logging(self) -> ros_cdk_core.IResolvable:
         '''Attribute IsLogging: Indicates whether the trail is logging API invocations.'''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrIsLogging"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrLatestDeliveryError")
     def attr_latest_delivery_error(self) -> ros_cdk_core.IResolvable:
         '''Attribute LatestDeliveryError: The last time an error occurred when the trail attempted to deliver log files.'''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrLatestDeliveryError"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrLatestDeliveryTime")
     def attr_latest_delivery_time(self) -> ros_cdk_core.IResolvable:
         '''Attribute LatestDeliveryTime: The date and time of the last successful delivery of a log file.'''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrLatestDeliveryTime"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrStartLoggingTime")
     def attr_start_logging_time(self) -> ros_cdk_core.IResolvable:
         '''Attribute StartLoggingTime: The most recent date and time when the user enables the trail.'''
         return typing.cast(ros_cdk_core.IResolvable, jsii.get(self, "attrStartLoggingTime"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="attrStopLoggingTime")
     def attr_stop_logging_time(self) -> ros_cdk_core.IResolvable:
         '''Attribute StopLoggingTime: The most recent date and time when the user disables the trail.'''
@@ -604,6 +682,10 @@ class TrailLoggingProps:
         :param enable: Property enable: Whether to enable the trail logging.
         :param name: Property name: The name of the trail to be enabled.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(TrailLoggingProps.__init__)
+            check_type(argname="argument enable", value=enable, expected_type=type_hints["enable"])
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
         self._values: typing.Dict[str, typing.Any] = {
             "enable": enable,
             "name": name,
@@ -670,6 +752,15 @@ class TrailProps:
         :param sls_project_arn: Property slsProjectArn: The unique ARN of the Log Service project.
         :param sls_write_role_arn: Property slsWriteRoleArn: The unique ARN of the Log Service role.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(TrailProps.__init__)
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
+            check_type(argname="argument oss_bucket_name", value=oss_bucket_name, expected_type=type_hints["oss_bucket_name"])
+            check_type(argname="argument role_name", value=role_name, expected_type=type_hints["role_name"])
+            check_type(argname="argument event_rw", value=event_rw, expected_type=type_hints["event_rw"])
+            check_type(argname="argument oss_key_prefix", value=oss_key_prefix, expected_type=type_hints["oss_key_prefix"])
+            check_type(argname="argument sls_project_arn", value=sls_project_arn, expected_type=type_hints["sls_project_arn"])
+            check_type(argname="argument sls_write_role_arn", value=sls_write_role_arn, expected_type=type_hints["sls_write_role_arn"])
         self._values: typing.Dict[str, typing.Any] = {
             "name": name,
             "oss_bucket_name": oss_bucket_name,
